@@ -59,7 +59,11 @@
      CONCAT2(oct_binop_, f));
 #endif
 
-class octave_serialport_common : public octave_base_value
+#ifdef HAVE_CONFIG_H
+#  include "../config.h"
+#endif
+
+class octave_serialport_common : public OCTAVE_BASE_CLASS
 {
 protected:
   octave_serialport_common();
@@ -83,7 +87,7 @@ public:
   // 4.4+
   bool isobject (void) const { return true;}
 
-  octave_base_value * unique_clone (void) { count++; return this;}
+  octave_base_value * unique_clone (void) { OV_COUNT++; return this;}
 
   // required to use subsasn
   string_vector map_keys (void) const { return fieldnames; }
@@ -165,6 +169,16 @@ public:
     userData = newv;
   }
 
+  std::string get_tag () const
+  {
+    return tag;
+  }
+
+  void set_tag (const std::string &newv)
+  {
+    tag = newv;
+  }
+
   int set_byteorder(const std::string& /* order */);
 
   std::string get_byteorder() const
@@ -189,6 +203,7 @@ protected:
   string_vector fieldnames;
   unsigned long byteswritten;
 
+  std::string tag;
   std::string name;
   std::string portPath;
   std::string byteOrder;
